@@ -3,7 +3,7 @@ import inspect
 import json
 import types
 from collections import deque
-from dataclasses import asdict, dataclass, field, fields, is_dataclass, make_dataclass
+from dataclasses import asdict, field, fields, is_dataclass, make_dataclass, _get_field
 from datetime import datetime
 from typing import Any, Optional
 
@@ -126,20 +126,22 @@ def get_supermodel_fields(
     plus extra version and timestamp fields
     if required per the supermodel options.
     """
-    field_names = [field.name for field in fields(cls)]
+    annotations = cls.__dict__.get("__annotations__", {})
 
     attrs = []
 
     if timestamped:
         for attr in ("_created", "_updated"):
-            if attr not in field_names:
+            if attr not in annotations:
                 attrs.append((attr, datetime, timestamp_field()))
 
-    if versioned:
-        if "_version" not in field_names:
-            attrs.append(("_version", int, version_field()))
+    if versioned and "_version" not in annotations:
+        attrs.append(("_version", int, version_field()))
 
-    attrs.extend([(field.name, field.type, field) for field in fields(cls)])
+    for name, annotation in cls.__dict__.get("__annotations__", {}).items():
+        field_def = getattr(cls, name, None)
+        kw_only = getattr(field_def, "kw_only", False) if field_def else False
+        attrs.append((name, annotation, _get_field(cls, name, annotation, kw_only)))
 
     return attrs
 
@@ -298,7 +300,7 @@ def supermodel(cls=None, **kwargs):
     """Provides the supermodel decorator for dataclasses."""
 
     def wrapper(cls):
-        kwargs["frozen"] = kwargs.get("frozen", True)
+        frozen = kwargs.pop("frozen", True)
         versioned = kwargs.pop("versioned", False)
         timestamped = kwargs.pop("timestamped", False)
 
@@ -322,15 +324,17 @@ def supermodel(cls=None, **kwargs):
             )
         )
 
-        dc = dataclass(cls, **kwargs)
+        field_defs = get_supermodel_fields(cls, versioned, timestamped)
 
         mro = inspect.getmro(cls)
         bases = tuple(c for c in mro if is_dataclass(c) and c != cls)
 
+        kwargs["frozen"] = frozen
+
         return make_dataclass(
-            dc.__name__,
+            cls.__name__,
             bases=bases,
-            fields=get_supermodel_fields(cls, versioned, timestamped),
+            fields=field_defs,
             namespace=namespace,
             **kwargs,
         )
