@@ -52,6 +52,9 @@ def get_datetime_pattern(datetime_format: str) -> Pattern[str]:
 
 def get_object_identifier(o: Any) -> str:
     """Returns the package-level identifier of the sender."""
+    if is_supermodel(o):
+        return o.__qualified_type__
+
     kind = o if inspect.isclass(o) else type(o)
     return f"{kind.__module__}.{kind.__qualname__}"
 
@@ -80,3 +83,13 @@ def is_supermodel(obj: Any) -> bool:
     """Returns True if the obj is a supermodel or an instance of a supermodel."""
     cls = obj if isinstance(obj, type) else type(obj)
     return is_dataclass(cls) and hasattr(cls, "_SUPERMODEL")
+
+
+def is_versioned(obj: Any) -> bool:
+    """Returns True if the obj is a supermodel and is versioned."""
+    return is_supermodel(obj) and obj._VERSIONED
+
+
+def is_timestamped(obj: Any) -> bool:
+    """Returns True if the obj is a supermodel and is timestamped."""
+    return is_supermodel(obj) and obj._TIMESTAMPED
